Class: Aws::IVSRealTime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IVSRealTime::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ivsrealtime/client.rb,
sig/client.rbs
Overview
An API client for IVSRealTime. To construct a client, you need to configure a :region and :credentials.
client = Aws::IVSRealTime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateEncoderConfigurationResponseSuccess, _CreateIngestConfigurationResponseSuccess, _CreateParticipantTokenResponseSuccess, _CreateStageResponseSuccess, _CreateStorageConfigurationResponseSuccess, _DeleteEncoderConfigurationResponseSuccess, _DeleteIngestConfigurationResponseSuccess, _DeletePublicKeyResponseSuccess, _DeleteStageResponseSuccess, _DeleteStorageConfigurationResponseSuccess, _DisconnectParticipantResponseSuccess, _GetCompositionResponseSuccess, _GetEncoderConfigurationResponseSuccess, _GetIngestConfigurationResponseSuccess, _GetParticipantResponseSuccess, _GetPublicKeyResponseSuccess, _GetStageResponseSuccess, _GetStageSessionResponseSuccess, _GetStorageConfigurationResponseSuccess, _ImportPublicKeyResponseSuccess, _ListCompositionsResponseSuccess, _ListEncoderConfigurationsResponseSuccess, _ListIngestConfigurationsResponseSuccess, _ListParticipantEventsResponseSuccess, _ListParticipantReplicasResponseSuccess, _ListParticipantsResponseSuccess, _ListPublicKeysResponseSuccess, _ListStageSessionsResponseSuccess, _ListStagesResponseSuccess, _ListStorageConfigurationsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartCompositionResponseSuccess, _StartParticipantReplicationResponseSuccess, _StopCompositionResponseSuccess, _StopParticipantReplicationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateIngestConfigurationResponseSuccess, _UpdateStageResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_encoder_configuration(params = {}) ⇒ Types::CreateEncoderConfigurationResponse
Creates an EncoderConfiguration object.
-
#create_ingest_configuration(params = {}) ⇒ Types::CreateIngestConfigurationResponse
Creates a new IngestConfiguration resource, used to specify the ingest protocol for a stage.
-
#create_participant_token(params = {}) ⇒ Types::CreateParticipantTokenResponse
Creates an additional token for a specified stage.
-
#create_stage(params = {}) ⇒ Types::CreateStageResponse
Creates a new stage (and optionally participant tokens).
-
#create_storage_configuration(params = {}) ⇒ Types::CreateStorageConfigurationResponse
Creates a new storage configuration, used to enable recording to Amazon S3.
-
#delete_encoder_configuration(params = {}) ⇒ Struct
Deletes an EncoderConfiguration resource.
-
#delete_ingest_configuration(params = {}) ⇒ Struct
Deletes a specified IngestConfiguration, so it can no longer be used to broadcast.
-
#delete_public_key(params = {}) ⇒ Struct
Deletes the specified public key used to sign stage participant tokens.
-
#delete_stage(params = {}) ⇒ Struct
Shuts down and deletes the specified stage (disconnecting all participants).
-
#delete_storage_configuration(params = {}) ⇒ Struct
Deletes the storage configuration for the specified ARN.
-
#disconnect_participant(params = {}) ⇒ Struct
Disconnects a specified participant from a specified stage.
-
#get_composition(params = {}) ⇒ Types::GetCompositionResponse
Get information about the specified Composition resource.
-
#get_encoder_configuration(params = {}) ⇒ Types::GetEncoderConfigurationResponse
Gets information about the specified EncoderConfiguration resource.
-
#get_ingest_configuration(params = {}) ⇒ Types::GetIngestConfigurationResponse
Gets information about the specified IngestConfiguration.
-
#get_participant(params = {}) ⇒ Types::GetParticipantResponse
Gets information about the specified participant token.
-
#get_public_key(params = {}) ⇒ Types::GetPublicKeyResponse
Gets information for the specified public key.
-
#get_stage(params = {}) ⇒ Types::GetStageResponse
Gets information for the specified stage.
-
#get_stage_session(params = {}) ⇒ Types::GetStageSessionResponse
Gets information for the specified stage session.
-
#get_storage_configuration(params = {}) ⇒ Types::GetStorageConfigurationResponse
Gets the storage configuration for the specified ARN.
-
#import_public_key(params = {}) ⇒ Types::ImportPublicKeyResponse
Import a public key to be used for signing stage participant tokens.
-
#list_compositions(params = {}) ⇒ Types::ListCompositionsResponse
Gets summary information about all Compositions in your account, in the AWS region where the API request is processed.
-
#list_encoder_configurations(params = {}) ⇒ Types::ListEncoderConfigurationsResponse
Gets summary information about all EncoderConfigurations in your account, in the AWS region where the API request is processed.
-
#list_ingest_configurations(params = {}) ⇒ Types::ListIngestConfigurationsResponse
Lists all IngestConfigurations in your account, in the AWS region where the API request is processed.
-
#list_participant_events(params = {}) ⇒ Types::ListParticipantEventsResponse
Lists events for a specified participant that occurred during a specified stage session.
-
#list_participant_replicas(params = {}) ⇒ Types::ListParticipantReplicasResponse
Lists all the replicas for a participant from a source stage.
-
#list_participants(params = {}) ⇒ Types::ListParticipantsResponse
Lists all participants in a specified stage session.
-
#list_public_keys(params = {}) ⇒ Types::ListPublicKeysResponse
Gets summary information about all public keys in your account, in the AWS region where the API request is processed.
-
#list_stage_sessions(params = {}) ⇒ Types::ListStageSessionsResponse
Gets all sessions for a specified stage.
-
#list_stages(params = {}) ⇒ Types::ListStagesResponse
Gets summary information about all stages in your account, in the AWS region where the API request is processed.
-
#list_storage_configurations(params = {}) ⇒ Types::ListStorageConfigurationsResponse
Gets summary information about all storage configurations in your account, in the AWS region where the API request is processed.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about AWS tags for the specified ARN.
-
#start_composition(params = {}) ⇒ Types::StartCompositionResponse
Starts a Composition from a stage based on the configuration provided in the request.
-
#start_participant_replication(params = {}) ⇒ Types::StartParticipantReplicationResponse
Starts replicating a publishing participant from a source stage to a destination stage.
-
#stop_composition(params = {}) ⇒ Struct
Stops and deletes a Composition resource.
-
#stop_participant_replication(params = {}) ⇒ Types::StopParticipantReplicationResponse
Stops a replicated participant session.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the AWS resource with the specified ARN.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
-
#update_ingest_configuration(params = {}) ⇒ Types::UpdateIngestConfigurationResponse
Updates a specified IngestConfiguration.
-
#update_stage(params = {}) ⇒ Types::UpdateStageResponse
Updates a stage’s configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ivsrealtime/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2549 2550 2551 |
# File 'lib/aws-sdk-ivsrealtime/client.rb', line 2549 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2552 2553 2554 |
# File 'lib/aws-sdk-ivsrealtime/client.rb', line 2552 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 |
# File 'lib/aws-sdk-ivsrealtime/client.rb', line 2522 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IVSRealTime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ivsrealtime' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#create_encoder_configuration(params = {}) ⇒ Types::CreateEncoderConfigurationResponse
Creates an EncoderConfiguration object.
86 |
# File 'sig/client.rbs', line 86
def create_encoder_configuration: (
|
#create_ingest_configuration(params = {}) ⇒ Types::CreateIngestConfigurationResponse
Creates a new IngestConfiguration resource, used to specify the ingest protocol for a stage.
103 |
# File 'sig/client.rbs', line 103
def create_ingest_configuration: (
|
#create_participant_token(params = {}) ⇒ Types::CreateParticipantTokenResponse
Creates an additional token for a specified stage. This can be done after stage creation or when tokens expire. Tokens always are scoped to the stage for which they are created.
Encryption keys are owned by Amazon IVS and never used directly by your application.
120 |
# File 'sig/client.rbs', line 120
def create_participant_token: (
|
#create_stage(params = {}) ⇒ Types::CreateStageResponse
Creates a new stage (and optionally participant tokens).
135 |
# File 'sig/client.rbs', line 135
def create_stage: (
|
#create_storage_configuration(params = {}) ⇒ Types::CreateStorageConfigurationResponse
Creates a new storage configuration, used to enable recording to Amazon S3. When a StorageConfiguration is created, IVS will modify the S3 bucketPolicy of the provided bucket. This will ensure that IVS has sufficient permissions to write content to the provided bucket.
155 |
# File 'sig/client.rbs', line 155
def create_storage_configuration: (
|
#delete_encoder_configuration(params = {}) ⇒ Struct
Deletes an EncoderConfiguration resource. Ensures that no Compositions are using this template; otherwise, returns an error.
168 |
# File 'sig/client.rbs', line 168
def delete_encoder_configuration: (
|
#delete_ingest_configuration(params = {}) ⇒ Struct
Deletes a specified IngestConfiguration, so it can no longer be used
to broadcast. An IngestConfiguration cannot be deleted if the
publisher is actively streaming to a stage, unless force is set to
true.
177 |
# File 'sig/client.rbs', line 177
def delete_ingest_configuration: (
|
#delete_public_key(params = {}) ⇒ Struct
Deletes the specified public key used to sign stage participant tokens. This invalidates future participant tokens generated using the key pair’s private key.
187 |
# File 'sig/client.rbs', line 187
def delete_public_key: (
|
#delete_stage(params = {}) ⇒ Struct
Shuts down and deletes the specified stage (disconnecting all
participants). This operation also removes the stageArn from the
associated IngestConfiguration, if there are participants using the
IngestConfiguration to publish to the stage.
196 |
# File 'sig/client.rbs', line 196
def delete_stage: (
|
#delete_storage_configuration(params = {}) ⇒ Struct
Deletes the storage configuration for the specified ARN.
If you try to delete a storage configuration that is used by a Composition, you will get an error (409 ConflictException). To avoid this, for all Compositions that reference the storage configuration, first use StopComposition and wait for it to complete, then use DeleteStorageConfiguration.
205 |
# File 'sig/client.rbs', line 205
def delete_storage_configuration: (
|
#disconnect_participant(params = {}) ⇒ Struct
Disconnects a specified participant from a specified stage. If the
participant is publishing using an IngestConfiguration,
DisconnectParticipant also updates the stageArn in the
IngestConfiguration to be an empty string.
214 |
# File 'sig/client.rbs', line 214
def disconnect_participant: (
|
#get_composition(params = {}) ⇒ Types::GetCompositionResponse
Get information about the specified Composition resource.
226 |
# File 'sig/client.rbs', line 226
def get_composition: (
|
#get_encoder_configuration(params = {}) ⇒ Types::GetEncoderConfigurationResponse
Gets information about the specified EncoderConfiguration resource.
236 |
# File 'sig/client.rbs', line 236
def get_encoder_configuration: (
|
#get_ingest_configuration(params = {}) ⇒ Types::GetIngestConfigurationResponse
Gets information about the specified IngestConfiguration.
246 |
# File 'sig/client.rbs', line 246
def get_ingest_configuration: (
|
#get_participant(params = {}) ⇒ Types::GetParticipantResponse
Gets information about the specified participant token.
256 |
# File 'sig/client.rbs', line 256
def get_participant: (
|
#get_public_key(params = {}) ⇒ Types::GetPublicKeyResponse
Gets information for the specified public key.
268 |
# File 'sig/client.rbs', line 268
def get_public_key: (
|
#get_stage(params = {}) ⇒ Types::GetStageResponse
Gets information for the specified stage.
278 |
# File 'sig/client.rbs', line 278
def get_stage: (
|
#get_stage_session(params = {}) ⇒ Types::GetStageSessionResponse
Gets information for the specified stage session.
288 |
# File 'sig/client.rbs', line 288
def get_stage_session: (
|
#get_storage_configuration(params = {}) ⇒ Types::GetStorageConfigurationResponse
Gets the storage configuration for the specified ARN.
299 |
# File 'sig/client.rbs', line 299
def get_storage_configuration: (
|
#import_public_key(params = {}) ⇒ Types::ImportPublicKeyResponse
Import a public key to be used for signing stage participant tokens.
309 |
# File 'sig/client.rbs', line 309
def import_public_key: (
|
#list_compositions(params = {}) ⇒ Types::ListCompositionsResponse
Gets summary information about all Compositions in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
322 |
# File 'sig/client.rbs', line 322
def list_compositions: (
|
#list_encoder_configurations(params = {}) ⇒ Types::ListEncoderConfigurationsResponse
Gets summary information about all EncoderConfigurations in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
336 |
# File 'sig/client.rbs', line 336
def list_encoder_configurations: (
|
#list_ingest_configurations(params = {}) ⇒ Types::ListIngestConfigurationsResponse
Lists all IngestConfigurations in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
348 |
# File 'sig/client.rbs', line 348
def list_ingest_configurations: (
|
#list_participant_events(params = {}) ⇒ Types::ListParticipantEventsResponse
Lists events for a specified participant that occurred during a specified stage session.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
362 |
# File 'sig/client.rbs', line 362
def list_participant_events: (
|
#list_participant_replicas(params = {}) ⇒ Types::ListParticipantReplicasResponse
Lists all the replicas for a participant from a source stage.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
377 |
# File 'sig/client.rbs', line 377
def list_participant_replicas: (
|
#list_participants(params = {}) ⇒ Types::ListParticipantsResponse
Lists all participants in a specified stage session.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
391 |
# File 'sig/client.rbs', line 391
def list_participants: (
|
#list_public_keys(params = {}) ⇒ Types::ListPublicKeysResponse
Gets summary information about all public keys in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
409 |
# File 'sig/client.rbs', line 409
def list_public_keys: (
|
#list_stage_sessions(params = {}) ⇒ Types::ListStageSessionsResponse
Gets all sessions for a specified stage.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
421 |
# File 'sig/client.rbs', line 421
def list_stage_sessions: (
|
#list_stages(params = {}) ⇒ Types::ListStagesResponse
Gets summary information about all stages in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
434 |
# File 'sig/client.rbs', line 434
def list_stages: (
|
#list_storage_configurations(params = {}) ⇒ Types::ListStorageConfigurationsResponse
Gets summary information about all storage configurations in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
446 |
# File 'sig/client.rbs', line 446
def list_storage_configurations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about AWS tags for the specified ARN.
457 |
# File 'sig/client.rbs', line 457
def list_tags_for_resource: (
|
#start_composition(params = {}) ⇒ Types::StartCompositionResponse
Starts a Composition from a stage based on the configuration provided in the request.
A Composition is an ephemeral resource that exists after this operation returns successfully. Composition stops and the resource is deleted:
-
When StopComposition is called.
-
After a 1-minute timeout, when all participants are disconnected from the stage.
-
After a 1-minute timeout, if there are no participants in the stage when StartComposition is called.
-
When broadcasting to the IVS channel fails and all retries are exhausted.
-
When broadcasting is disconnected and all attempts to reconnect are exhausted.
467 |
# File 'sig/client.rbs', line 467
def start_composition: (
|
#start_participant_replication(params = {}) ⇒ Types::StartParticipantReplicationResponse
Starts replicating a publishing participant from a source stage to a destination stage.
533 |
# File 'sig/client.rbs', line 533
def start_participant_replication: (
|
#stop_composition(params = {}) ⇒ Struct
Stops and deletes a Composition resource. Any broadcast from the Composition resource is stopped.
546 |
# File 'sig/client.rbs', line 546
def stop_composition: (
|
#stop_participant_replication(params = {}) ⇒ Types::StopParticipantReplicationResponse
Stops a replicated participant session.
562 |
# File 'sig/client.rbs', line 562
def stop_participant_replication: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the AWS resource with the specified ARN.
573 |
# File 'sig/client.rbs', line 573
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
583 |
# File 'sig/client.rbs', line 583
def untag_resource: (
|
#update_ingest_configuration(params = {}) ⇒ Types::UpdateIngestConfigurationResponse
Updates a specified IngestConfiguration. Only the stage ARN attached to the IngestConfiguration can be updated. An IngestConfiguration that is active cannot be updated.
594 |
# File 'sig/client.rbs', line 594
def update_ingest_configuration: (
|
#update_stage(params = {}) ⇒ Types::UpdateStageResponse
Updates a stage’s configuration.
606 |
# File 'sig/client.rbs', line 606
def update_stage: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2542 2543 2544 |
# File 'lib/aws-sdk-ivsrealtime/client.rb', line 2542 def waiter_names [] end |