Class: Aws::IVSRealTime::Types::CreateIngestConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivsrealtime/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

Application-provided attributes to store in the IngestConfiguration and attach to a stage. Map keys and values can contain UTF-8 encoded text. The maximum length of this field is 1 KB total. *This field is exposed to all stage participants and should not be used for personally identifying, confidential, or sensitive information.*



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ingest_protocolString

Type of ingest protocol that the user employs to broadcast. If this is set to RTMP, insecureIngest must be set to true.



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#insecure_ingestBoolean

Whether the stage allows insecure RTMP ingest. This must be set to true, if ingestProtocol is set to RTMP. Default: false.



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Optional name that can be specified for the IngestConfiguration being created.



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stage_arnString

ARN of the stage with which the IngestConfiguration is associated.



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags attached to the resource. Array of maps, each of the form ‘string:string (key:value)`. See [Best practices and strategies][1] in *Tagging AWS Resources and Tag Editor* for details, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no constraints on tags beyond what is documented there.

[1]: docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

Customer-assigned name to help identify the participant using the IngestConfiguration; this can be used to link a participant to a user in the customer’s own systems. This can be any UTF-8 encoded text. *This field is exposed to all stage participants and should not be used for personally identifying, confidential, or sensitive information.*



431
432
433
434
435
436
437
438
439
440
441
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 431

class CreateIngestConfigurationRequest < Struct.new(
  :name,
  :stage_arn,
  :user_id,
  :attributes,
  :ingest_protocol,
  :insecure_ingest,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end