Class: Aws::IVSRealTime::Types::IngestConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivsrealtime/types.rb

Overview

Object specifying an ingest configuration.

Constant Summary collapse

SENSITIVE =
[:stream_key]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Ingest configuration ARN.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#attributesHash<String,String>

Application-provided attributes to to store in the IngestConfiguration and attach to a stage. Map keys and values can contain UTF-8 encoded text. The maximum length of this field is 1 KB total. *This field is exposed to all stage participants and should not be used for personally identifying, confidential, or sensitive information.*

Returns:

  • (Hash<String,String>)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#ingest_protocolString

Type of ingest protocol that the user employs for broadcasting.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#nameString

Ingest name

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#participant_idString

ID of the participant within the stage.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#redundant_ingestBoolean

Indicates whether redundant ingest is enabled for the ingest configuration.

Returns:

  • (Boolean)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#redundant_ingest_credentialsArray<Types::RedundantIngestCredential>

A list of redundant ingest credentials, present only when ‘redundantIngest` is set to `true`. See [Redundant Ingest] in *IVS RTMP Publishing* for details.

[1]: docs.aws.amazon.com/ivs/latest/RealTimeUserGuide/rt-rtmp-publishing.html#redundant-ingest



1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#stage_arnString

ARN of the stage with which the IngestConfiguration is associated.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#stateString

State of the ingest configuration. It is ‘ACTIVE` if a publisher currently is publishing to the stage associated with the ingest configuration.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#stream_keyString

Ingest-key value for the RTMP(S) protocol.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#tagsHash<String,String>

Tags attached to the resource. Array of maps, each of the form ‘string:string (key:value)`. See [Best practices and strategies] in *Tagging AWS Resources and Tag Editor* for details, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no constraints on tags beyond what is documented there.

[1]: docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html

Returns:

  • (Hash<String,String>)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end

#user_idString

Customer-assigned name to help identify the participant using the IngestConfiguration; this can be used to link a participant to a user in the customer’s own systems. This can be any UTF-8 encoded text. *This field is exposed to all stage participants and should not be used for personally identifying, confidential, or sensitive information.*

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 1469

class IngestConfiguration < Struct.new(
  :name,
  :arn,
  :ingest_protocol,
  :stream_key,
  :stage_arn,
  :participant_id,
  :state,
  :user_id,
  :redundant_ingest,
  :redundant_ingest_credentials,
  :attributes,
  :tags)
  SENSITIVE = [:stream_key]
  include Aws::Structure
end