Class: Aws::IVSRealTime::Types::PipConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVSRealTime::Types::PipConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivsrealtime/types.rb
Overview
Configuration information specific to Picture-in-Picture (PiP) layout, for [server-side composition].
[1]: docs.aws.amazon.com/ivs/latest/RealTimeUserGuide/server-side-composition.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#featured_participant_attribute ⇒ String
This attribute name identifies the featured slot.
-
#grid_gap ⇒ Integer
Specifies the spacing between participant tiles in pixels.
-
#omit_stopped_video ⇒ Boolean
Determines whether to omit participants with stopped video in the composition.
-
#participant_order_attribute ⇒ String
Attribute name in ParticipantTokenConfiguration identifying the participant ordering key.
-
#pip_behavior ⇒ String
Defines PiP behavior when all participants have left: ‘STATIC` (maintains original position/size) or `DYNAMIC` (expands to full composition).
-
#pip_height ⇒ Integer
Specifies the height of the PiP window in pixels.
-
#pip_offset ⇒ Integer
Sets the PiP window’s offset position in pixels from the closest edges determined by ‘PipPosition`.
-
#pip_participant_attribute ⇒ String
Specifies the participant for the PiP window.
-
#pip_position ⇒ String
Determines the corner position of the PiP window.
-
#pip_width ⇒ Integer
Specifies the width of the PiP window in pixels.
-
#video_fill_mode ⇒ String
Defines how video content fits within the participant tile: ‘FILL` (stretched), `COVER` (cropped), or `CONTAIN` (letterboxed).
Instance Attribute Details
#featured_participant_attribute ⇒ String
This attribute name identifies the featured slot. A participant with this attribute set to ‘“true”` (as a string value) in ParticipantTokenConfiguration is placed in the featured slot. Default: `“”` (no featured participant).
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#grid_gap ⇒ Integer
Specifies the spacing between participant tiles in pixels. Default: ‘0`.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#omit_stopped_video ⇒ Boolean
Determines whether to omit participants with stopped video in the composition. Default: ‘false`.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#participant_order_attribute ⇒ String
Attribute name in ParticipantTokenConfiguration identifying the participant ordering key. Participants with ‘participantOrderAttribute` set to `“”` or not specified are ordered based on their arrival time into the stage.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#pip_behavior ⇒ String
Defines PiP behavior when all participants have left: ‘STATIC` (maintains original position/size) or `DYNAMIC` (expands to full composition). Default: `STATIC`.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#pip_height ⇒ Integer
Specifies the height of the PiP window in pixels. When this is not set explicitly, ‘pipHeight`’s value will be based on the size of the composition and the aspect ratio of the participant’s video.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#pip_offset ⇒ Integer
Sets the PiP window’s offset position in pixels from the closest edges determined by ‘PipPosition`. Default: `0`.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#pip_participant_attribute ⇒ String
Specifies the participant for the PiP window. A participant with this attribute set to ‘“true”` (as a string value) in ParticipantTokenConfiguration is placed in the PiP slot. Default: `“”` (no PiP participant).
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#pip_position ⇒ String
Determines the corner position of the PiP window. Default: ‘BOTTOM_RIGHT`.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#pip_width ⇒ Integer
Specifies the width of the PiP window in pixels. When this is not set explicitly, ‘pipWidth`’s value will be based on the size of the composition and the aspect ratio of the participant’s video.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |
#video_fill_mode ⇒ String
Defines how video content fits within the participant tile: ‘FILL` (stretched), `COVER` (cropped), or `CONTAIN` (letterboxed). Default: `COVER`.
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 2630 class PipConfiguration < Struct.new( :featured_participant_attribute, :omit_stopped_video, :video_fill_mode, :grid_gap, :pip_participant_attribute, :pip_behavior, :pip_offset, :pip_position, :pip_width, :pip_height, :participant_order_attribute) SENSITIVE = [] include Aws::Structure end |