Class: Aws::IVSRealTime::Types::StopParticipantReplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVSRealTime::Types::StopParticipantReplicationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivsrealtime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_stage_arn ⇒ String
ARN of the stage where the participant has been replicated.
-
#participant_id ⇒ String
Participant ID of the publisher that has been replicated.
-
#source_stage_arn ⇒ String
ARN of the stage where the participant is publishing.
Instance Attribute Details
#destination_stage_arn ⇒ String
ARN of the stage where the participant has been replicated.
3304 3305 3306 3307 3308 3309 3310 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 3304 class StopParticipantReplicationRequest < Struct.new( :source_stage_arn, :destination_stage_arn, :participant_id) SENSITIVE = [] include Aws::Structure end |
#participant_id ⇒ String
Participant ID of the publisher that has been replicated. This is assigned by IVS and returned by CreateParticipantToken or the ‘jti` (JWT ID) used to [ create a self signed token].
3304 3305 3306 3307 3308 3309 3310 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 3304 class StopParticipantReplicationRequest < Struct.new( :source_stage_arn, :destination_stage_arn, :participant_id) SENSITIVE = [] include Aws::Structure end |
#source_stage_arn ⇒ String
ARN of the stage where the participant is publishing.
3304 3305 3306 3307 3308 3309 3310 |
# File 'lib/aws-sdk-ivsrealtime/types.rb', line 3304 class StopParticipantReplicationRequest < Struct.new( :source_stage_arn, :destination_stage_arn, :participant_id) SENSITIVE = [] include Aws::Structure end |